lynx-dev
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

lynx-dev [dev15] patch for mouse key buglet (was: Re: Nitsy "reset" disp


From: Kim DeVaughn
Subject: lynx-dev [dev15] patch for mouse key buglet (was: Re: Nitsy "reset" display buglet)
Date: Fri, 5 Feb 1999 11:07:15 -0800

On Fri, Feb 05, 1999, Klaus Weide (address@hidden) said:
|
| Well I traced this a bit (for the Form Options SELECT case), and it
| it the result of a change to the key mapping code (which I prefer not
| to get into...)

A wise idea, IMHO ...


| LYStrings.h has changed from
|
|    #define DO_NOTHING      270     /* 0x10E */
| to
|    #define MOUSE_KEY       270     /* 0x10E */
|    #define DO_NOTHING      271     /* 0x10F */
|
| but the tables in LYKeymap.c where not kept in synch with this change,

Attached is a patch that fixes the problem on this platform (FreeBSD),
using this (gcc) compiler, with slang.

I've no idea if it works elsewhere, what with all the ifdef's in the key
code, so others will need to look at it too (and Ilya, in particular).

Also, I've not tested it very thoroughly here for possible side-effects,
though I haven't seen any yet.  Caveat emptor.

/kim


Against 2.8.2dev.15:

--- ../../lynx-2.8.2-dev.15+kd.orig/src/LYKeymap.h      Thu Jan 28 08:31:29 1999
+++ LYKeymap.h  Fri Feb  5 10:31:06 1999
@@ -106,15 +106,16 @@
 #define       LYK_ELGOTO        73
 #define       LYK_CHANGE_LINK   74
 #define              LYK_EDIT_TEXTAREA 75
+#define       LYK_MOUSE_KEY     76
 
 #ifdef USE_EXTERNALS
-#define       LYK_EXTERN        76
+#define       LYK_EXTERN        77
 #if defined(VMS) || defined(DIRED_SUPPORT)
-#define       LYK_DIRED_MENU    77
+#define       LYK_DIRED_MENU    78
 #endif /* VMS || DIRED_SUPPORT */
 #else  /* USE_EXTERNALS */
 #if defined(VMS) || defined(DIRED_SUPPORT)
-#define       LYK_DIRED_MENU    76
+#define       LYK_DIRED_MENU    77
 #endif /* VMS || DIRED_SUPPORT */
 #endif /* !defined(USE_EXTERNALS) */
 
##--eof--##

reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- ../../lynx-2.8.2-dev.15+kd.orig/src/LYKeymap.c      Tue Feb  2 01:35:07 1999
+++ LYKeymap.c  Fri Feb  5 10:45:24 1999
@@ -229,8 +229,8 @@
 LYK_HELP,         LYK_ACTIVATE,     LYK_HOME,       LYK_END,
 /* F1*/          /* Do key */      /* Find key */  /* Select key */
 
-LYK_UP_TWO,       LYK_DOWN_TWO,
-/* Insert key */  /* Remove key */
+LYK_UP_TWO,       LYK_DOWN_TWO,     LYK_MOUSE_KEY,
+/* Insert key */  /* Remove key */  /* rodent dummy */
 
 LYK_DO_NOTHING,
 /* DO_NOTHING*/
@@ -519,8 +519,8 @@
    0,                  0,              0,              0,
 /* F1*/          /* Do key */      /* Find key */  /* Select key */
 
-   0,                  0,
-/* Insert key */  /* Remove key */
+   0,                  0,              0,
+/* Insert key */  /* Remove key */  /* rodent dummy */
 
 LYK_DO_NOTHING,
 /* DO_NOTHING*/
@@ -608,6 +608,7 @@
 { "ELGOTO",            "edit the current link's URL or ACTION and go to it" },
 { "CHANGE_LINK",       "force reset of the current link on the page" },
 { "EDITTEXTAREA",      "use an external editor to edit a form's textarea" },
+{ "MOUSE_KEY",         "dummy entry for wayward rodents (say cheese ...)" },
 #ifdef USE_EXTERNALS
 { "EXTERN",            "run external program with url" },
 #endif